@@ -11,7 +11,7 @@
 # * name comes from http://www.thefreedictionary.com/cleave      #
 ##################################################################
 
-Version = '3.1'
+Version = '3.2'
 Build = '1'
 
 import sys
@@ -44,6 +44,10 @@ reaverBinary         = 'reaver'
 reaverDatabase       = 'reaver.db'
 washBinary           = 'wash'
 
+skipSplash           = 'skipSplash'
+skipKernelCheck      = 'skipKernelCheck'
+skipVersionCheck     = 'skipVersionCheck'
+
 ##############################################################
 
 def showMessage(message):
@@ -78,7 +82,10 @@ class clevenMainWindow(QtGui.QMainWindow):
        QtCore.QObject.connect(self.ui.pushButtonCapturePackets,      QtCore.SIGNAL('clicked()'), self.showCaptureWindow)
        QtCore.QObject.connect(self.ui.pushButtonDeleleCaptured,      QtCore.SIGNAL('clicked()'), self.showDeleteWindow)
 
-       self.showStartupDialog()          ## (Un)comment for pop-up of the start-up dialog at start-up
+       if not os.path.isfile(pathStorage + '/' + skipSplash):
+          self.showStartupDialog()          ## (Un)comment for pop-up of the start-up dialog at start-up
+       else: 
+          print "INFO: skipping Splash screen - user request"
        # self.showConfigureDriversDialog() ## (Un)comment for pop-up of the configuration dialog at start-up  
        
     def showAboutWindow(self):
@@ -203,20 +210,20 @@ class clevenCapture(QtGui.QMainWindow):
           rValues = filter(None, rValues)                   ##remove unknown (empty)
           for i in rValues:                                 ##iterate on the values stored in the list
              newList = i.split()                            ##split each line into a list
-             print 'The WPS AP is:\n',newList
+             print 'INFO: The WPS AP is:\n',newList
              newValue = newList[5]                          ##keep the 5th element only
              values.append(newValue)                        ##append the AP into a new list
-          print 'The WPS clean list is:\n',values
+          print 'INFO: The WPS clean list is:\n',values
        else:
           values = os.popen('sudo %s/%s readESSIDs %s %s' %(pathMain, helperScript, pathStorage, encryption)).read()
           values = values.lstrip(" ")                       ##remove trailing space from first ESSID
           values = values.replace("\n ","\n")               ##remove trailing space from the rest of the ESSIDs 
           values = values.split("\n")                       ##split them to create an entry for each in the list
-          # print 'The WEP/WPA list is:\n',values
+          # print 'INFO: The WEP/WPA list is:\n',values
 
        values = filter(None, values)                        ##remove unknown (hidden)
        values.sort(key=str.lower)                           ##sort them by name.
-       # print 'The final list is:\n',values
+       # print 'INFO: The final list is:\n',values
        self.ui.scanList.addItems(values)
 
     def displayNetworkInformation(self): #FIXME: read wlan info directly and not from a file.
@@ -373,20 +380,26 @@ class clevenConfigureDrivers(QtGui.QDialog):
     def getKernelVersion(self):
 
        global kernelVersion
-       kernelVersion = os.popen('uname -r').read().strip('\n').strip('')
-       print "Version of Kernel found: ", kernelVersion
-              
-       if kernelVersion == '2.6.28.10-power50':
-          pass
-       else: 
-          message = 'WARNING: The system did not find a known compatible kernel version for the injection drivers.\n\nThe application might not work properly..'
-          showMessage(message)
+       if os.path.isfile(pathStorage + '/' + skipKernelCheck):
+          kernelVersion = '2.6.28.10-power50'
+          print "INFO: override of kernel version - user request"
+       else:
+          kernelVersion = os.popen('uname -r').read().strip('\n').strip('')
+          print "INFO: Version of Kernel found: ", kernelVersion
 
+       if not os.path.isfile(pathStorage + '/' + skipVersionCheck):
+          if kernelVersion == '2.6.28.10-power50':
+             pass
+          else: 
+             message = 'WARNING: The system did not find a known compatible kernel version for the injection drivers.\n\nThe application might not work properly..'
+             showMessage(message)
+       else:
+          print "INFO: Check of kernel version compatibility skipped - user request"
+          
     def getDriversState(self):
        '''Check the state of the Drivers (Stock/Bleeding)'''
        
        global driverStateInjection
-       
        DRIVERS = os.popen('cat /proc/modules | grep wl12xx').read()
        
        if DRIVERS == '':
@@ -806,6 +819,7 @@ class clevenAbout(QtGui.QMainWindow):
        <br><br>Additional information on the usage, settings and implications can be found in the wiki pages (see buttons in the end). 
        <br><br><b>THANKS TO:</b> 
        <br><br><b>David Gnedt</b> (lxp) for the development of the bleeding-edge wlan drivers. You can support his work by sending him your donations. See for more info: http://david.gnedt.eu/blog/wl1251/ 
+       <br><br><b>Ivaylo Dimitrov</b> (freemangordon) for the packaging of the bleeding-edge wlan drivers. 
        <br><br><b>Benoit HERVIER</b> at http://khertan.net/ for the code used in this about window. 
        <br></center>''' % (Version, Build))
        
@@ -886,25 +900,25 @@ class clevenMain():
     if os.path.exists(pathReaver):
        if os.path.isfile(pathReaver + '/' + reaverBinary):
           if os.WEXITSTATUS(os.system('sudo %s/%s copyReaver %s %s' % ( pathMain, helperScript, pathReaver, pathMain ))) == 0:
-             print 'found Reaver binary and made a copy'
+             print 'INFO: found Reaver binary and made a copy'
        if os.path.isfile(pathReaver + '/' + washBinary):
           if os.WEXITSTATUS(os.system('sudo %s/%s copyWash %s %s' % ( pathMain, helperScript, pathReaver, pathMain ))) == 0:
-             print 'found Wash binary and made a copy'
+             print 'INFO: found Wash binary and made a copy'
        if os.path.isfile(pathReaver + '/' + reaverDatabase):
           if os.WEXITSTATUS(os.system('sudo %s/%s copyReaverDB %s %s' % ( pathMain, helperScript, pathReaver, pathMain ))) == 0:
-             print 'found Reaver database and made a copy'
+             print 'INFO: found Reaver database and made a copy'
 
     ##Check if reaver is available to the application:
     if os.path.isfile(pathMain + '/' + reaverBinary):
        os.path.exists(pathReaver) or os.mkdir(pathReaver)
        reaverAvailability = True
-       print 'Reaver is available for usage..'
+       print 'INFO: Reaver is available for usage..'
        
     ##Check if wash is available to the application:
     if os.path.isfile(pathMain + '/' + washBinary):
        os.path.exists(pathReaver) or os.mkdir(pathReaver)
        washAvailability = True
-       print 'Wash is available for usage..'
+       print 'INFO: Wash is available for usage..'
        
     app = QtGui.QApplication(sys.argv)
     myapp = clevenMainWindow()
