@@ -4,7 +4,20 @@
 DRIVERPATH="/opt/lib/modules/$1/" 
 FILEPATH="/home/user/.cleven"
 
-# Save mac address
+# Check if needed files exist
+if [ -f $DRIVERPATH/updates/compat/compat.ko ] &&
+   [ -f $DRIVERPATH/updates/net/rfkill/rfkill_backport.ko ] &&
+   [ -f $DRIVERPATH/updates/net/wireless/cfg80211.ko ] &&
+   [ -f $DRIVERPATH/updates/net/mac80211/mac80211.ko ] &&
+   [ -f $DRIVERPATH/updates/drivers/net/wireless/wl1251/wl1251.ko ] &&
+   [ -f $DRIVERPATH/updates/drivers/net/wireless/wl1251/wl1251_spi.ko ]; then 
+    echo "INFO: Driver files found.."
+else 
+    echo "ERROR: Some or all driver files are missing. Interrupting this action."
+    exit
+fi
+
+# Read MAC address (and store it if it's the first time) 
 MACADDR="`ifconfig wlan0 | sed -n 's/.*HWaddr \([0-9A-Fa-f:]\+\).*/\1/p'`"
 
 if [ ! -f $FILEPATH/myMAC ]; then
@@ -20,8 +33,8 @@ rmmod cfg80211 2>/dev/null
 rmmod rfkill_backport 2>/dev/null
 rmmod compat_firmware_class 2>/dev/null
 rmmod compat 2>/dev/null
-# Load bleeding-edge wl1251
 
+# Load bleeding-edge wl1251
 insmod $DRIVERPATH/updates/compat/compat.ko
 insmod $DRIVERPATH/updates/net/rfkill/rfkill_backport.ko
 insmod $DRIVERPATH/updates/net/wireless/cfg80211.ko
@@ -32,4 +45,4 @@ insmod $DRIVERPATH/updates/drivers/net/wireless/wl1251/wl1251_spi.ko
 # Restore mac address
 ifconfig wlan0 down hw ether "$MACADDR"
 
-echo "Custom wl1251 module loaded (with injection) :)"
\ No newline at end of file
+echo "INFO: Custom wl1251 module loaded (with injection) :)"
\ No newline at end of file
